@@ -106,6 +106,8 @@ void snd_entry (char *b, size_t blen, MUTTMENU *menu, int num)
 
 
 
+
+
 static void draw_envelope (HEADER *msg, char *fcc)
 {
   char buf[STRING];
@@ -151,6 +153,18 @@ static void draw_envelope (HEADER *msg, char *fcc)
   addstr (fcc);
 
 
+
+
+
+
+
+
+
+
+
+
+
+
   mvaddstr (HDR_ATTACH - 1, 0, "===== Attachments =====");
 }
 
@@ -371,6 +385,21 @@ int mutt_send_menu (HEADER *msg,   /* structure for new message */
 	menu->redraw = REDRAW_FULL;
 	break;
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
       case OP_COMPOSE_ATTACH_FILE:
 	fname[0] = 0;
 	if (mutt_enter_fname ("Attach file", fname, sizeof (fname),
@@ -538,15 +567,15 @@ int mutt_send_menu (HEADER *msg,   /* structure for new message */
 
 	  CLEARLINE (LINES-1);
 	  fname[0] = 0;
-	  if (mutt_get_field ("New file: ", fname, sizeof (fname), M_FILE) != 0 ||
-								    !fname[0])
+	  if (mutt_get_field ("New file: ", fname, sizeof (fname), M_FILE) != 0
+	      || !fname[0])
 	    continue;
 	  mutt_expand_path (fname, sizeof (fname));
 
 	  /* Call to lookup_mime_type () ?  maybe later */
 	  type[0] = 0;
-	  if (mutt_get_field ("Content-Type: ", type, sizeof (type), 0) != 0 ||
-								    !type[0])
+	  if (mutt_get_field ("Content-Type: ", type, sizeof (type), 0) != 0 
+	      || !type[0])
 	    continue;
 
 	  if (!(p = strchr (type, '/')))
@@ -595,7 +624,19 @@ int mutt_send_menu (HEADER *msg,   /* structure for new message */
 	  idx[menu->current]->content->subtype = safe_strdup (p);
 	  idx[menu->current]->content->unlink = 1;
 	  menu->redraw |= REDRAW_INDEX | REDRAW_STATUS;
+
+	  if (mutt_compose_attachment (idx[menu->current]->content))
+	  {
+	    mutt_update_encoding (idx[menu->current]->content);
+	    menu->redraw = REDRAW_FULL;
+	  }
 	}
+	break;
+
+
+
+
+
 
       case OP_COMPOSE_EDIT_MIME:
 	CHECK_COUNT;
@@ -632,6 +673,11 @@ int mutt_send_menu (HEADER *msg,   /* structure for new message */
 	  menu->redraw = REDRAW_CURRENT; /* cte might have changed */
 	break;
 
+
+
+
+
+
       case OP_EXIT:
 	if ((i = query_quadoption (OPT_POSTPONE, "Postpone this message?")) == M_NO)
 	{
@@ -667,6 +713,11 @@ int mutt_send_menu (HEADER *msg,   /* structure for new message */
 	mutt_system (buf);
 	break;
 
+
+
+
+
+
     }
   }
 
