@@ -62,6 +62,7 @@ enum
 
 
 
+  MENU_QUERY,
   MENU_MAX
 };
 
@@ -90,6 +91,7 @@ extern struct binding_t OpPager[];
 extern struct binding_t OpCompose[];
 extern struct binding_t OpBrowser[];
 extern struct binding_t OpEditor[];
+extern struct binding_t OpQuery[];
 
 
 #include "keymap_defs.h"
