@@ -41,8 +41,6 @@ static struct mapping_t PostponeHelp[] = {
 
 
 
-
-
 static short PostCount = 0;
 static time_t LastModify = 0;
 static CONTEXT *PostContext = NULL;
@@ -52,7 +50,7 @@ int mutt_num_postponed (void)
   struct stat st;
   CONTEXT ctx;
 
-  if (stat (Postponed, &st) == -1)
+  if (!Postponed || stat (Postponed, &st) == -1)
   {
      PostCount = 0;
      LastModify = 0;
@@ -91,15 +89,9 @@ int mutt_num_postponed (void)
 
 static void post_entry (char *s, size_t slen, MUTTMENU *menu, int entry)
 {
-  char buf[SHORT_STRING] = { 0 };
   CONTEXT *ctx = (CONTEXT *) menu->data;
 
-  rfc822_write_address (buf, sizeof (buf), ctx->hdrs[entry]->env->to);
-  snprintf (s, slen, "%2d %c %-20.20s     %s",
-	    entry + 1,
-	    ctx->hdrs[entry]->deleted ? 'D' : ' ',
-	    buf,
-	    ctx->hdrs[entry]->env->subject);
+  mutt_make_string (s, slen, NONULL (HdrFmt), ctx, ctx->hdrs[entry]);
 }
 
 static HEADER *select_msg (void)
@@ -179,6 +171,9 @@ int mutt_get_postponed (CONTEXT *ctx, HEADER *hdr, HEADER **cur)
   char *p;
   int opt_delete;
 
+  if (!Postponed)
+    return (-1);
+
   if ((PostContext = mx_open_mailbox (Postponed, M_NOSORT, NULL)) == NULL)
   {
     PostCount = 0;
@@ -295,21 +290,15 @@ int mutt_get_postponed (CONTEXT *ctx, HEADER *hdr, HEADER **cur)
 
   for (tmp = hdr->env->userhdrs; tmp; )
   {
-    if (ctx && strncmp ("X-Mutt-References:", tmp->data, 18) == 0)
+    if (strncasecmp ("X-Mutt-References:", tmp->data, 18) == 0)
     {
-      int j;
-
-      p = tmp->data + 18;
-      SKIPWS (p);
-
-      for (j=0; j < ctx->msgcount; j++)
+      if (ctx)
       {
-	if (ctx->hdrs[j]->env->message_id &&
-	    strcmp (ctx->hdrs[j]->env->message_id, p) == 0)
-	{
-	  *cur = ctx->hdrs[j];
-	  break;
-	}
+	/* if a mailbox is currently open, look to see if the orignal message
+	   the user attempted to reply to is in this mailbox */
+	p = tmp->data + 18;
+	SKIPWS (p);
+	*cur = hash_find (ctx->id_hash, p);
       }
 
       /* Remove the X-Mutt-References: header field. */
@@ -324,6 +313,12 @@ int mutt_get_postponed (CONTEXT *ctx, HEADER *hdr, HEADER **cur)
       if (*cur)
 	code |= SENDREPLY;
     }
+
+
+
+
+
+
     else
     {
       last = tmp;
@@ -333,3 +328,5 @@ int mutt_get_postponed (CONTEXT *ctx, HEADER *hdr, HEADER **cur)
   return (code);
 }
 
+
+
