@@ -24,10 +24,18 @@
 #define dprint(N,X) 
 #endif
 
-#define mutt_make_string(A,B,C,D) _mutt_make_string(A,B,C,D,0)
-void _mutt_make_string (char *, size_t, char *, HEADER *, int);
+#define NONULL(x) x?x:""
 
-const char *mutt_extract_token (char *, size_t, const char *, char *, size_t, int);
+#define MoreArgs(p) (*p->dptr && *p->dptr != ';' && *p->dptr != '#')
+
+#define mutt_make_string(A,B,C,D,E) _mutt_make_string(A,B,C,D,E,0)
+void _mutt_make_string (char *, size_t, const char *, CONTEXT *,
+	HEADER *, format_flag);
+
+int mutt_extract_token (BUFFER *, BUFFER *, int);
+
+int mutt_add_string (BUFFER *, const char *);
+int mutt_add_char (BUFFER *, char);
 
 #define mutt_system(x) _mutt_system(x,0)
 int _mutt_system (const char *, int);
@@ -44,13 +52,19 @@ int _mutt_aside_thread (HEADER *, short, short);
 #define mutt_new_header() safe_calloc (1, sizeof (HEADER))
 #define mutt_new_envelope() safe_calloc (1, sizeof (ENVELOPE))
 
+typedef const char * format_t (char *, size_t, char, const char *, const char *, const char *, const char *, unsigned long, format_flag);
+
+void mutt_FormatString (char *, size_t, const char *, format_t *, unsigned long, format_flag);
+
 void mutt_update_encoding (BODY *a);
 
+FILE *mutt_open_read (const char *, pid_t *);
+
 void set_quadoption (int, int);
 int query_quadoption (int, const char *);
 int quadoption (int);
 
-ADDRESS *mutt_default_from (void);
+ADDRESS *mutt_lookup_alias (const char *s);
 ADDRESS *mutt_remove_duplicates (ADDRESS *);
 ADDRESS *mutt_expand_aliases (ADDRESS *);
 ADDRESS *mutt_parse_adrlist (ADDRESS *, const char *);
@@ -82,21 +96,24 @@ char *mutt_read_line (char *, size_t *, FILE *, int *);
 char *mutt_strlower (char *);
 char *mutt_skip_whitespace (char *);
 char *mutt_substrcpy (char *, const char *, const char *, size_t);
+char *mutt_substrdup (const char *, const char *);
 
+void mutt_add_child_pid (pid_t);
 void mutt_alias_menu (char *, size_t, ALIAS *);
 void mutt_block_signals (void);
 void mutt_block_signals_system (void);
 void mutt_body_handler (BODY *, STATE *);
 void mutt_bounce_message (HEADER *, ADDRESS *);
 void mutt_buffy (char *);
+void mutt_check_rescore (CONTEXT *ctx);
 void mutt_clear_error (void);
-void mutt_create_alias (ENVELOPE *);
+void mutt_create_alias (ENVELOPE *, ADDRESS *);
 void mutt_decode_attachment (BODY *, STATE *);
 void mutt_default_save (char *, size_t, HEADER *);
 void mutt_display_address (ADDRESS *);
 void mutt_edit_file (const char *, const char *);
 void mutt_edit_headers (const char *, const char *, HEADER *, char *, size_t);
-void mutt_error (const char *, ...);
+void mutt_curses_error (const char *, ...);
 void mutt_enter_command (void);
 void mutt_exit (int);
 void mutt_expand_fmt (char *, size_t, const char *, const char *);
@@ -113,10 +130,12 @@ void mutt_generate_header (char *, size_t, HEADER *, int);
 void mutt_help (int);
 void mutt_index_menu (void);
 void mutt_init_history (void);
+void mutt_linearize_tree (CONTEXT *, int);
 void mutt_make_help (char *, size_t, char *, int, int);
 void mutt_message (const char *, ...);
 void mutt_message_to_7bit (BODY *, FILE *);
 void mutt_mktemp (char *);
+void mutt_nocurses_error (const char *, ...);
 void mutt_normalize_time (struct tm *);
 void mutt_parse_mime_message (CONTEXT *ctx, HEADER *);
 void mutt_pipe_message_to_state (HEADER *, STATE *);
@@ -126,7 +145,9 @@ void mutt_pretty_size (char *, size_t, long);
 void mutt_print_message (HEADER *);
 void mutt_remove_trailing_ws (char *);
 void mutt_query_exit (void);
+void mutt_query_menu (char *, size_t);
 void mutt_safe_path (char *s, size_t l, ADDRESS *a);
+void mutt_save_path (char *s, size_t l, ADDRESS *a);
 void mutt_score_message (HEADER *);
 void mutt_select_fcc (char *, size_t, HEADER *);
 void mutt_select_file (char *, size_t, int);
@@ -160,7 +181,9 @@ int mutt_check_menu (const char *);
 int mutt_check_mime_type (const char *);
 int mutt_check_month (const char *);
 int mutt_check_overwrite (const char *, const char *, char *, size_t, int);
+int mutt_command_complete (char *, size_t, int);
 int mutt_complete (char *);
+int mutt_compose_attachment (BODY *a);
 int mutt_copy_bytes (FILE *, FILE *, size_t);
 int mutt_copy_stream (FILE *, FILE *);
 int mutt_decode_save_attachment (FILE *, BODY *, char *, int, int);
@@ -178,20 +201,22 @@ int mutt_is_text_type (int, char *);
 int mutt_is_valid_mailbox (const char *);
 int mutt_needs_mailcap (BODY *);
 int mutt_num_postponed (void);
-int mutt_parse_bind (const char *, unsigned long, char *, size_t);
-int mutt_parse_color (const char *, unsigned long, char *, size_t);
-int mutt_parse_hook (const char *, unsigned long, char *, size_t);
-int mutt_parse_macro (const char *, unsigned long, char *, size_t);
-int mutt_parse_mailboxes (const char *s, unsigned long, char *, size_t);
-int mutt_parse_mono (const char *, unsigned long, char *, size_t);
-int mutt_parse_push (const char *, unsigned long, char *, size_t);
-int mutt_parse_rc_line (const char *, char *, int);
-int mutt_parse_score (const char *, unsigned long, char *, size_t);
-int mutt_parse_unscore (const char *, unsigned long, char *, size_t);
+int mutt_parse_bind (BUFFER *, BUFFER *, unsigned long, BUFFER *);
+int mutt_parse_color (BUFFER *, BUFFER *, unsigned long, BUFFER *);
+int mutt_parse_uncolor (BUFFER *, BUFFER *, unsigned long, BUFFER *);
+int mutt_parse_hook (BUFFER *, BUFFER *, unsigned long, BUFFER *);
+int mutt_parse_macro (BUFFER *, BUFFER *, unsigned long, BUFFER *);
+int mutt_parse_mailboxes (BUFFER *, BUFFER *, unsigned long, BUFFER *);
+int mutt_parse_mono (BUFFER *, BUFFER *, unsigned long, BUFFER *);
+int mutt_parse_push (BUFFER *, BUFFER *, unsigned long, BUFFER *);
+int mutt_parse_rc_line (/* const */ char *, BUFFER *, BUFFER *);
+int mutt_parse_score (BUFFER *, BUFFER *, unsigned long, BUFFER *);
+int mutt_parse_unscore (BUFFER *, BUFFER *, unsigned long, BUFFER *);
 int mutt_pattern_func (int, char *, HEADER *);
 int mutt_pipe_attachment (FILE *, BODY *, const char *, char *); 
 int mutt_pipe_message (HEADER *);
 int mutt_print_attachment (FILE *, BODY *);
+int mutt_query_complete (char *, size_t);
 int mutt_save_attachment (FILE *, BODY *, char *, int);
 int mutt_save_message (HEADER *, int, int, int *);
 int mutt_search_command (int, int);
@@ -207,14 +232,17 @@ int mutt_write_mime_body (BODY *, FILE *);
 int mutt_write_mime_header (BODY *, FILE *);
 int mutt_write_rfc822_header (FILE *, ENVELOPE *, BODY *, int);
 int mutt_yesorno (const char *, int);
+void mutt_cache_index_colors(CONTEXT *);
+void mutt_set_header_color(CONTEXT *, HEADER *);
 
 int mh_valid_message (const char *);
 
 pid_t mutt_create_filter (const char *, FILE **, FILE **, FILE **);
 pid_t mutt_create_filter_fd (const char *, FILE **, FILE **, FILE **, int, int, int);
 
-char *safe_strdup (const char *);
+#define FREE(x) safe_free((void **)x)
 
+char *safe_strdup (const char *);
 void *safe_calloc (size_t, size_t);
 void *safe_malloc (unsigned int);
 void safe_realloc (void **, size_t);
@@ -239,6 +267,13 @@ ADDRESS *alias_reverse_lookup (ADDRESS *);
 	((unsigned char)(c) >= 0xa0)))
 #endif
 
+#define new_pattern() safe_calloc(1, sizeof (pattern_t))
+
+int mutt_pattern_exec (struct pattern_t *pat, pattern_exec_flag flags, CONTEXT *ctx, HEADER *h);
+pattern_t *mutt_pattern_comp (/* const */ char *s, int flags, BUFFER *err);
+void mutt_check_simple (char *s, size_t len, const char *simple);
+void mutt_pattern_free (pattern_t **pat);
+
 /* ----------------------------------------------------------------------------
  * Prototypes for broken systems
  */
